<?php
/**
 * Tooltip Plugin: Create tooltips for sections of wikitext.
 *
 *   syntax: {{tooltip:style|text>tooltip_wikitext}}
 *
 * @file       tooltip/syntax.php
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     'Ryan.Chappelle' <visuallucho_plusplus at yahoo dot es>
 * @brief      CSS-based inline toltips
 * @version    1.0
 *
 *   This plugin allows to insert "tooltips" in DokuWiki text, so that 
 *  hovering the mouse over the mrked text will reveal the tooltip.
 *  The wikitext that composes the tooltip is (unfortunely) not parsed
 *  in any way, but otherwise the plugins is perfectly usable.
 *   This plugin uses CSS only; no JavaScript or server side help
 *  (beyond the actual tag parsing) is used to harm any animal, 
 *  in any way.
 *
 *   For a live demo point your browser to: http://informatica.temuco.udelmar.cl/~lmachuca/dokuwiki-lucho/desarrollo/informatica/dokuwiki/plugin-tooltip 
 *
 * or simply head to the DokuWiki plugin page (plugin:tooltip) and 
 * click the link that says "Live Demo".
 *
 *   My page is in Spanish; i've tried for it to be neuter enough for 
 *  online tools to provide good translations.
 *
 *  Greetings.
 *        - ryan.chappelle
 */

if(!defined('DW_LF')) define('DW_LF',"\n");
 
if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../').'/');
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'syntax.php');
 
 
class syntax_plugin_tooltip extends DokuWiki_Syntax_Plugin
{
    function getInfo()
    {
        return array(
            'author' => 'ryan.chappelle',
            'email'  => 'visuallucho_plusplus@yahoo.es',
            'date'   => '2008-05-21',
            'name'   => 'Tooltip Plugin',
            'desc'   => 'Tooltips for sections of wikitext',
            'url'    => 'http://wiki.splitbrain.org/plugin:tooltip',
        );
    }
 
    function getType()
        { return 'substition'; }
 
    
    function getAllowedTypes()
    {
        return array();
    }
    
 
    function getPType()
        { return 'normal'; }
 
    function getSort()
        { return 399; } // should "almost" conflict with "{{}}" wikisyntax
 
    function connectTo($mode)
    {
        $this->Lexer->addEntryPattern( 
        "<ttip:.*?>(?=.*?</ttip>)", 
        $mode, 
        'plugin_tooltip');
    }

    function postConnect() 
    {
        $this->Lexer->addExitPattern(
        "</ttip>",
        'plugin_tooltip');
    }


    function handle($match, $state, $pos, &$handler)
    {
        
        // remove the delimiters
        //$match= substr($match,6,-7);
        // the expected format is <ttip:class>mark|content</ttip>
        // (where "class" may be empty)

        $data= array();
        $data['state']= $state;

        switch ($state)  {
          case DOKU_LEXER_ENTER: 
            $class= substr($match, 6, -1);
            if ( $class == "" ) {
              $class= "default";
              }
            $data['class']= $class;
            break;
          
          case DOKU_LEXER_UNMATCHED:
            list( $mark, $content)= explode( "|", $match);
            // check for default style
            $data['mark']= $mark;
            $data['content']= $content;
            break;

          } // end switch ($state)
        return $data;
    } // end function
 
    function render($mode, &$renderer, $data)
    {
        
        $state= $data['state'];
        $style= "tooltip_". $data['class'];
        $mark= $data['mark'];
        $content= $data['content'];

        if($mode == 'xhtml')
        {
            /* let's do the jon thingie, that is, 
               create the HTML code that reveals the tooltip
             */
            switch ($state) {
              case DOKU_LEXER_ENTER:
                $renderer->doc.= '<span class="'. $style. '">' .DW_LF;
                break;
              case DOKU_LEXER_UNMATCHED:
                $renderer->doc.= '<a href="#">';
                $renderer->doc.= $mark;
                $renderer->doc.= '<span class="tip">';
                $renderer->doc.= $content. '</span>';
                $renderer->doc.= '</a>';
                break;
              case DOKU_LEXER_EXIT:
                $renderer->doc.= '</span>'. DW_LF  ; //end div of mark
                break;
            } // end switch
            return true;
        } // end if (xhtml)


        return false;
    }
}
